/*
 * Copyright (C) 2012-2013  Cedric Cheneau
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.holmes.core;

import net.holmes.core.common.Service;
import org.junit.Test;

import static org.easymock.EasyMock.*;

public class HolmesServerTest {

    @Test
    public void testHolmesServer() {
        Service service = createMock(Service.class);

        HolmesServer holmesServer = new HolmesServer(service, service, service, service, System.getProperty("java.io.tmpdir"));

        service.start();
        expectLastCall().times(4);
        service.stop();
        expectLastCall().times(4);

        replay(service);
        holmesServer.start();
        holmesServer.stop();
        verify(service);
    }

    @Test(expected = RuntimeException.class)
    public void testHolmesServerStartTwoServers() {
        Service service = createMock(Service.class);

        HolmesServer holmesServer = new HolmesServer(service, service, service, service, System.getProperty("java.io.tmpdir"));
        HolmesServer holmesServer2 = new HolmesServer(service, service, service, service, System.getProperty("java.io.tmpdir"));

        service.start();
        expectLastCall().times(4);
        service.stop();
        expectLastCall().times(4);

        replay(service);
        try {
            holmesServer.start();
            holmesServer2.start();
        } finally {
            holmesServer.stop();
            verify(service);
        }
    }
}
